package at.ac.uibk.gitsearch.service.dto;

import at.ac.uibk.gitsearch.domain.enumeration.ReviewStatus;
import java.io.Serializable;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class ReviewRatingDTO {

    Long id;
    String comment;
    String status;
    Long reviewId;
    Long userId;

    public ReviewRatingDTO() {}

    public ReviewRatingDTO(String comment, String status) {
        this.comment = comment;
        this.status = status;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getComment() {
        return comment;
    }

    public void setComment(String comment) {
        this.comment = comment;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    /**
     * holds a count of the review stati as Map.
     *
     * @author Michael Breu
     *
     */
    public static class ReviewStatisticsDTO implements Serializable {

        private static final Logger LOGGER = LoggerFactory.getLogger(ReviewStatisticsDTO.class);
        /**
         * serialVersionUID
         */
        private static final long serialVersionUID = 7584249169269270589L;

        /*
         * Review In Progress
         * Review improved
         * Review completed
         */
        private int reviewInProgress = 0;
        private int reviewImproved = 0;
        private int reviewCompleted = 0;
        private int unknownStats = 0;

        private int reviewsRequestedByUser = 0;
        private int reviewInProgressByUser = 0;
        private int reviewImprovementRequestedByUser = 0;
        private int reviewCompletedByUser = 0;
        private int unknownStatsByUser = 0;

        private int badgesRewarded = 0;

        public int getReviewInProgress() {
            return reviewInProgress;
        }

        public void setReviewInProgress(int reviewInProgress) {
            this.reviewInProgress = reviewInProgress;
        }

        public int getReviewImproved() {
            return reviewImproved;
        }

        public void setReviewImproved(int reviewImproved) {
            this.reviewImproved = reviewImproved;
        }

        public int getReviewCompleted() {
            return reviewCompleted;
        }

        public void setReviewCompleted(int reviewCompleted) {
            this.reviewCompleted = reviewCompleted;
        }

        public int getUnknownStats() {
            return unknownStats;
        }

        public void setUnknownStats(int unknownStats) {
            this.unknownStats = unknownStats;
        }

        public void put(ReviewStatus status, int count) {
            switch (status) {
                case REVIEW_IN_PROGRESS:
                    reviewInProgress = count;
                    break;
                case REVIEW_IMPROVED:
                    reviewImproved = count;
                    break;
                case REVIEW_COMPLETED:
                    reviewCompleted = count;
                    break;
                default:
                    LOGGER.error("status {} not yet supported!", status);
                    unknownStats += count;
                    break;
            }
        }

        public void putByUser(ReviewStatus status, int count) {
            if (status == null) {
                reviewsRequestedByUser = count;
                return;
            }
            switch (status) {
                case REVIEW_IN_PROGRESS:
                    reviewInProgressByUser = count;
                    break;
                case IMPROVEMENTS_REQUESTED:
                    reviewImprovementRequestedByUser = count;
                    break;
                case REVIEW_COMPLETED:
                    reviewCompletedByUser = count;
                    break;
                default:
                    LOGGER.error("status {} not yet supported!", status);
                    unknownStats += count;
                    break;
            }
        }

        public int getReviewsRequestedByUser() {
            return reviewsRequestedByUser;
        }

        public void setReviewsRequestedByUser(int reviewsRequestedByUser) {
            this.reviewsRequestedByUser = reviewsRequestedByUser;
        }

        public int getReviewInProgressByUser() {
            return reviewInProgressByUser;
        }

        public void setReviewInProgressByUser(int reviewInProgressByUser) {
            this.reviewInProgressByUser = reviewInProgressByUser;
        }

        public int getReviewCompletedByUser() {
            return reviewCompletedByUser;
        }

        public void setReviewCompletedByUser(int reviewCompletedByUser) {
            this.reviewCompletedByUser = reviewCompletedByUser;
        }

        public int getUnknownStatsByUser() {
            return unknownStatsByUser;
        }

        public void setUnknownStatsByUser(int unknownStatsByUser) {
            this.unknownStatsByUser = unknownStatsByUser;
        }

        public int getReviewImprovementRequestedByUser() {
            return reviewImprovementRequestedByUser;
        }

        public void setReviewImprovementRequestedByUser(int reviewImprovementRequestedByUser) {
            this.reviewImprovementRequestedByUser = reviewImprovementRequestedByUser;
        }

        public int getBadgesRewarded() {
            return badgesRewarded;
        }

        public void setBadgesRewarded(int badgedRewarded) {
            this.badgesRewarded = badgedRewarded;
        }
    }

    public Long getReviewId() {
        return reviewId;
    }

    public void setReviewId(Long reviewId) {
        this.reviewId = reviewId;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
}
